from setuptools import setup, find_packages

classifiers = [

    "development_status = 3 - Alpha",
    "license = OSI Approved :: MIT License",
    "intended_audience = Developers",
    "programming_language = 3 - Python 3",
    "operating_system = Any"
]





setup(
    name = "QuantGates",
    version = "0.0.1",
    author = "Akash Deep",
    author_email = "akash.deep@ttu.edu",
    description = "A Python package for Visualizing Quantum Gates on a Bloch Sphere",
    descriptionfile = open("README.md").read(),
    url = ""
)
